@@ -11,7 +11,7 @@ LIST_SEPARATOR = "\n"
 class PythonSetupBuilder(TemplateBuilder):
     def handle_ini_values(self, values: Union[str, List[str]]):
         # Turn list into a single block of text values
-        return (LIST_SEPARATOR + LIST_SEPARATOR.join(values)) if isinstance(values, list) else values
+        return (LIST_SEPARATOR + LIST_SEPARATOR.join([self.relative_path(str(v)) for v in values])) if isinstance(values, list) else values
 
     def build(self, setup_py_template: str, setup_cfg_files: List[str], setup_items: dict):
         # Copy setup.py
